import type { VxeGridProps } from '#/adapter/vxe-table';

import { DictEnum } from '@vben/constants';

import { type FormSchemaGetter } from '#/adapter/form';
import { getDictOptions } from '#/utils/dict';
import { renderDict } from '#/utils/render';
import { getPopupContainer } from '@vben/utils';

export const querySchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    fieldName: 'name',
    label: '备件名称'
  },
  {
    component: 'Input',
    fieldName: 'code',
    label: '备件编码'
  },
  {
    component: 'Input',
    fieldName: 'modelNo',
    label: '备件型号'
  },
  {
    component: 'Input',
    fieldName: 'madeIn',
    label: '生产产商'
  },
  {
    component: 'Input',
    fieldName: 'supplier',
    label: '供应商'
  }
];

export const columns: VxeGridProps['columns'] = [
  { type: 'checkbox', width: 60, fixed: 'left' },
  {
    title: '备件预览',
    field: 'imgUrl',
    showOverflow: true,
    width: 100,
    fixed: 'left',
    align: 'center',
    slots: { default: 'imgUrl' }
  },
  {
    title: '备件名称',
    field: 'name',
    fixed: 'left',
    align: 'center',
    width: 200
  },
  {
    title: '备件编码',
    field: 'code',
    width: 140
  },
  {
    title: '备件型号',
    field: 'modelNo',
    width: 100
  },
  {
    title: '备件类型',
    field: 'typeName',
    width: 100
  },
  {
    title: '生产产商',
    field: 'madeIn',
    width: 140
  },
  {
    title: '供应商',
    field: 'supplier',
    width: 140
  },
  {
    title: '计量单位',
    field: 'unit',
    sortable: true,
    slots: {
      default: ({ row }) => {
        if (row.unit === null || row.unit === '') {
          return '';
        }
        return renderDict(row.unit, DictEnum.EIMS_SPARE_UNIT);
      }
    },
    width: 100
  },
  {
    title: '参考价',
    field: 'referPrice',
    sortable: true,
    width: 120
  },
  {
    title: '库存上限',
    field: 'upperStock',
    sortable: true,
    width: 120
  },
  {
    title: '库存下限',
    field: 'lowerStock',
    width: 120
  },
  {
    title: '实际库存',
    field: 'actualStock',
    width: 120
  },
  {
    title: '库存金额',
    field: 'stockAmount',
    width: 120
  },
  {
    title: '更换周期',
    field: 'replaceCycle',
    width: 120
  },
  {
    title: '备注',
    field: 'remark',
    width: 120
  },
  {
    field: 'action',
    fixed: 'right',
    slots: { default: 'action' },
    title: '操作',
    width: 180
  }
];

export const drawerSchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'id'
  },
  {
    component: 'TreeSelect',
    defaultValue: 0,
    fieldName: 'type',
    label: '备件类型',
    rules: 'selectRequired'
  },
  {
    component: 'Input',
    fieldName: 'name',
    label: '备件名称',
    rules: 'required'
  },
  {
    component: 'Input',
    fieldName: 'code',
    label: '备件编码',
    rules: 'required'
  },
  {
    component: 'Input',
    fieldName: 'img',
    dependencies: {
      show: () => false,
      triggerFields: ['imgUrl']
    },
    label: '备件预览',
  },
  {
    component: 'Input',
    fieldName: 'imgUrl',
    label: '备件预览'
  },
  {
    component: 'Input',
    fieldName: 'modelNo',
    label: '型号'
  },
  {
    component: 'Input',
    fieldName: 'madeIn',
    label: '生产产商'
  },
  {
    component: 'Input',
    fieldName: 'supplier',
    label: '供应商'
  },
  {
    component: 'InputNumber',
    fieldName: 'referPrice',
    label: '参考价格',
    componentProps: {
      min: 0,
      precision: 2,
      addonAfter: '￥',
      placeholder: '请输入'
    }
  },
  {
    component: 'InputNumber',
    fieldName: 'upperStock',
    label: '库存上限',
    componentProps: {
      min: 0
    }
  },
  {
    component: 'InputNumber',
    fieldName: 'lowerStock',
    label: '库存下限',
    componentProps: {
      min: 0
    }
  },
  {
    component: 'InputNumber',
    fieldName: 'actualStock',
    formItemClass: 'col-span-1',
    label: '实际库存',
    componentProps: {
      min: 0
    }
  },
  {
    component: 'Select',
    componentProps: {
      getPopupContainer,
      options: getDictOptions(DictEnum.EIMS_SPARE_UNIT)
    },
    fieldName: 'unit',
    formItemClass: 'col-span-1 w-[80px]',
    labelWidth: 0,
    label: ''
  },
  {
    component: 'InputNumber',
    fieldName: 'stockAmount',
    label: '库存金额',
    componentProps: {
      min: 0,
      precision: 2,
      addonAfter: '￥',
      placeholder: '请输入'
    }
  },
  {
    component: 'InputNumber',
    fieldName: 'replaceCycle',
    formItemClass: 'col-span-1',
    label: '更换周期',
    componentProps: {
      min: 0
    }
  },
  {
    component: 'Select',
    componentProps: {
      getPopupContainer,
      options: getDictOptions(DictEnum.MAINT_CYCLE_UNIT)
    },
    fieldName: 'cycleUnit',
    formItemClass: 'col-span-1 w-[80px]',
    labelWidth: 0,
    label: ''
  },
  {
    component: 'Textarea',
    formItemClass: 'items-baseline',
    fieldName: 'remark',
    label: '备注'
  }
];
